Metadata

Trait Metadata 

pub trait Metadata {
    // Required methods
    fn op_write<T: AsRef<[u8]>>(&mut self, key: &[u8], value: T) -> Result<()>;
    fn op_read(&self, key: &[u8]) -> Result<Option<Vec<u8>>>;
}

Required Methods

fn op_write<T: AsRef<[u8]>>(&mut self, key: &[u8], value: T) -> Result<()>

Assigns an value to a key in the Metadata CF

fn op_read(&self, key: &[u8]) -> Result<Option<Vec<u8>>>

Reads an value of a key from the Metadata CF

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors